Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(71)

Unified Diff: ios/chrome/browser/tabs/tab.h

Issue 2694263004: Removed CRWSessionEntry from Tab's interface. (Closed)
Patch Set: remove unused function Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ios/chrome/browser/tabs/tab.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/chrome/browser/tabs/tab.h
diff --git a/ios/chrome/browser/tabs/tab.h b/ios/chrome/browser/tabs/tab.h
index f65e1ea44d10143f57de08e99dbaac65e6f0e369..163c827457e667e8de1a2aa9fe11a39a6add8bf8 100644
--- a/ios/chrome/browser/tabs/tab.h
+++ b/ios/chrome/browser/tabs/tab.h
@@ -19,7 +19,6 @@
@class AutoReloadBridge;
@class CastController;
@protocol CRWNativeContentProvider;
-@class CRWSessionEntry;
@class CRWWebController;
@class ExternalAppLauncher;
@class FormInputAccessoryViewController;
@@ -57,6 +56,7 @@ struct SessionTab;
}
namespace web {
+class NavigationItem;
class NavigationManagerImpl;
struct Referrer;
class WebState;
@@ -246,8 +246,8 @@ extern NSString* const kProxyPassthroughHeaderValue;
(const std::vector<sessions::SerializedNavigationEntry>&)navigations
currentIndex:(NSInteger)currentIndex;
-// Navigate forwards or backwards to |entry|.
-- (void)goToEntry:(CRWSessionEntry*)entry;
+// Navigate forwards or backwards to |item|.
+- (void)goToItem:(const web::NavigationItem*)item;
- (void)reload;
// Navigates forwards or backwards.
« no previous file with comments | « no previous file | ios/chrome/browser/tabs/tab.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698